-- Chart of Account for Poland
-- From: Peter Dabrowski <meritage@mail.com>
-- Sun, 23 March 2003
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('000000000','Aktywa Trwae','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('001000000','rodki Trwae','A','','A','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('001010000','Grunty wasne i prawa wieczystego uytkowania gruntw','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('001020000','Budynki, locale i obiekty inynierii ldowej i wodnej','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('001030000','Urzdzenia techniczne i maszyny','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('001040000','rodki transportu','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('001050000','Inne rodki trwae','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('002000000','Wartoci niematerialne i prawne','A','','A','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('002010000','Koszty zakoczonych prac rozwojowych','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('002020000','Nabyta warto firmy','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('002080000','Inne wartoci niematerialne i prawne','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('002090000','Zaliczki na wartoci niematerialne i prawne','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('003000000','Dugoterminowe aktywa finansowe','A','','A','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('003010000','W jednostkach powizanych','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('003010100','Udziay lub akcje','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('003010200','Inne papiery wartociowe','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('003010300','Udzielone porzyczki','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('003010400','Inne dugoterminowe aktywa finansowe','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('003020000','W pozostaych jednostkach','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('003020100','Udziay lub akcje','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('003020200','Inne papiery wartociowe','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('003020300','Udzielone poyczki','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('003020400','Inne dugoterminowe aktywa finansowe','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('003090000','Inne investycje dugoterminowe','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('003090100','Inne rodzaje dugoterminowych aktyww finansowych','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('004000000','Investycje w nieruchomoci i prawa','A','','A','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('004010000','Nieruchomoci','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('004020000','Wartoci niematerialne i prawne','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('005000000','Dugoterminowe rozliczenia midzyokresowe','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('005010000','Aktywa z tytuu odroczonego podatku dochodowego','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('005020000','Inne rozliczenia midzyokresowe','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('006000000','Nalenoci dugoterminowe','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('006010000','Od jednostek powizanych','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('006020000','Od pozostaych jednostek','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('007000000','Odpisy umorzeniowe rodkw trwaych oraz wartoci niematerialnych i prawnych','A','','A','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('007010000','Odpisy umorzeniowe wartoci gruntw i prawa wieczystego uytkowania gruntw','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('007020000','Odpisy umorzeniowe budynkw, lokali i obiektw inynierii ldowej i wodnej','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('007030000','Odpisy umorzeniowe urzdze technicznych i maszyn','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('007040000','Odpisy umorzeniowe rodkw transportu','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('007050000','Odpisy umorzeniowe ulepsze obcych rodkw trwaych','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('007090000','Odpisy umorzeniowe innych rodkw trwaych','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('008000000','rodki trwae w budowie','A','','A','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('008010000','Inwestycje budowy rodka trwaego','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('008020000','Ulepszenia rodka trwaego','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('008030000','Nakady na budow rodka trwaego','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('008040000','Zaliczki na rodki trwae w budowie','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('008050000','Ulepszenia obcych rodkw trwaych','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('009000000','Odpisy aktualizujce dugoterminowe aktywa finansowe','A','','A','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('009010000','Odpisy aktualizujce udziay i akcje w obcych jednostkach','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('009020000','Odpisy aktualizujce lokaty','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('009030000','Odpisy aktualizujce udzielone porzyczki dugoterminowe','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('009090000','Odpisy aktualizujce inne rodzaje dugoterminowych aktyww finansowych','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('100000000','rodki pienine, rachunki bankowe oraz inne krtkoterminowe aktywa finansowe','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('110000000','rodki pienine w kasie','A','','A','AR:AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('110010000','Kasa krajowych rodkw pieninych','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('110020000','Kasa zagranicznych rodkw pieninych','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('113000000','Rachunki i kredyty bankowe','A','','A','AR:AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('113010000','Rachunek biecy','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('113020000','Rachunek rodkw wyodrbnionych i zablokowanych','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('113030000','Rachunki kredytw bankowych','A','','A','AR_paid:AP_amount:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('113040000','Rachunek rodkw walutowych','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('114000000','Krtkoterminowe aktywa finansowe','A','','A','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('114010000','Krtkoterminowe aktywa finansowe w jednostkach powizanych','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('114010100','Udziay lub akcje','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('114010200','Inne papiery wartociowe','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('114010300','Udzielone poyczki','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('114010400','Inne krtkoterminowe aktywa finansowe','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('114020000','Krtkoterminowe aktywa finansowe w pozostaych jednostkach','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('114020100','Udziay lub akcje','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('114020200','Inne papiery wartociowe','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('114020400','Inne krtkoterminowe aktywa finansowe','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('115000000','Inne rodki pienine','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('116000000','Inne aktywa pienine','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('117000000','Inne inwestycje krtkoterminowe','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('118000000','Krtkoterminowe rozliczenia midzyokresowe','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('200000000','Rozrachunki i roszczenia','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('220000000','Nalenoci krtkoterminowe','A','','L','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('220010000','Nalenoci od jednostek powizanych','A','','L','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('220010100','Nalenoci z tytuu dostaw i usug','A','','L','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('220010110','Nalenoci z tytuu dostaw i usug, o okresie spaty do 12 miesicy','A','','L','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('220010120','Nalenoci z tytuu dostaw i usug, o okresie spaty powyej 12 miesicy','A','','L','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('220010200','Inne nalenoci','A','','L','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('220010210','Zobowizania z tytuu pokrycia kosztw oglnego zarzdu','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('220010220','Zobowizania z tytuu rozlicze VAT','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('221010000','Nalenoci od pozostaych jednostek','A','','L','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('221020100','Nalenoci z tytuu dostaw i usug','A','','L','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('221020110','Nalenoci z tytuu dostaw i usug, o okresie spaty do 12 miesicy','A','','L','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('221020120','Nalenoci z tytuu dostaw i usug, o okresie spaty powyej 12 miesicy','A','','L','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('221020200','Nalenoci z tytuu podatkw, dotacji, ce, ubezpiecze spoecznych i zdrowotnych oraz innych wiadcze','A','','L','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('221020300','Zaliczki przekazane dostawcom','A','','L','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('221020400','Nalenoci dochodzone na drodze sdowej','A','','L','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('221020500','Inne nalenoci','A','','L','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222000000','Zobowizania krtkoterminowe','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222010000','Zobowizania wobec jednostek powiazanych','A','','L','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222010100','Zobowizania z tytuu dostaw i usug','A','','L','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222010200','Zobowizania o okresie wymagalnoci do 12 miesicy','A','','L','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222010300','Zobowizania o okresie wymagalnoci powyej 12 miesicy','A','','L','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222010400','Inne zobowizania','A','','L','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222020000','Zobowizania wobec pozostaych jednostek','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222020100','Kredyty i poyczki','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222020200','Zobowizania z tytuu emisji dunych papierw wartociowych','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222020300','Inne zobowizania finasowe','A','','L','AP_Amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222020400','Zobowiazania z tytuu dostaw i usug','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222020500','Zobowizania o okresie wymagalnoci do 12 miesicy ','A','','L','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222020600','Zobowizania o okresie wymagalnoci powyej 12 miesiy','A','','L','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222020700','Zaliczki otrzmane na dostawy','A','','L','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222020800','Zobowizania wekslowe','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222020900','Zobowizania z tytuu podatkw, ce, ubezpiecze i innych wiadcze','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222021000','Zobowizania z tytuu wynagrodze','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('222021100','Inne zobowizania','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223000000','Rozrachunki publicznoprawne','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223010000','Rozrachunki z urzdem skarbowym z tytuu VAT','A','','L','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223020000','Rozliczenie nalenego VAT','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223020100','Rozliczenie nalenego VAT-22%','A','','L','AR_tax:IC_taxpart:IC_taxservice');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223020200','Rozliczenie nalenego VAT-7%','A','','L','AR_tax:IC_taxpart:IC_taxservice');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223020300','Rozliczenie nalenego VAT-0%','A','','L','AR_tax:IC_taxpart:IC_taxservice');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223030000','Rozliczenie naliczonego VAT','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223030100','Rozliczenie naliczonego VAT-22%','A','','L','AP_tax:IC_taxpart:IC_taxservice');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223030200','Rozliczenie naliczonego VAT-7%','A','','L','AP_tax:IC_taxpart:IC_taxservice');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223030300','Rozliczenie naliczonego VAT-0%','A','','L','AP_tax:IC_taxpart:IC_taxservice');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223040000','Korekty naliczonego VAT','A','','L','AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223050000','Rozrachunki z Urzdem Celnym','A','','L','AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223060000','Rozrachunki z Urzdem Skarbowym z tytuu znakw akcyzy','A','','L','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223070000','Rozrachunki z Urzdem Skarbowym z tytuu podatku akcyzowego','A','','L','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223080000','Rozliczenie znakw akcyzy','A','','L','AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223090000','Rozrachunki z ZUS','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223100000','Rozrachunki z Urzdem Skarbowym z tytuu podatku dochodowego od osb prawnych','A','','L','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('224000000','Rozrachunki z pracownikami','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('224010000','Rozrachunki z tytuu wynagrodze','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('224020000','Rozrachunki z tytuu poyczek udzielonych pracownikom','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('224090000','Inne rozrachunki z pracownikami','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225000000','Zobowizania dugoterminowe','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225010000','Zobowizania wobec jednostek powizanych','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225010100','Zobowizania z tytuu wyodrbnienia skadnikw majtkowych','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225010200','Zobowizania z tytuu podziau zysku','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225020000','Zobowizania wobec pozostaych jednostek','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225020100','Kredyty i poyczki otrzymane','A','','L','AR_amount:AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225020200','Kredyty i poyczki udzielone','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225020300','Zobowizania z tytuu emisji dunych papierw wartociowych','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225020400','Inne zobowizania kredytowe','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225020500','Inne zobowizania','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225030000','Rozrachunki z tytuu wpat na kapita zakadowy','A','','L','AR_amount:APamount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225040000','Rozrachunki z tytuu wkadw niepieninych na kapita zakadowy','A','','L','AR_amount:AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225050000','Rozrachunki z tytuu podwyszenia kapitau ze rodkw wasnych spki','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225060000','Rozrachunki z tytuu umorzenia udziaw wasnych','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225070000','Rozrachunki z tytuu dywident','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225080000','Rozrachunki z tytuu dopat i zwrotu dopat','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('225090000','Pozostae rozrachunki ze wsplnikami','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('229000000','Odpisy aktualizujce rozrachunki','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('300000000','Materiay i towary','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('330000000','Rozliczenie zakupu','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('330010000','Rozliczenie wartoci materiaw i towarw w drodze','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('330020000','Wartoci dostaw niefakturowanych','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('330030000','Przychody wszelkich dostaw i usug i ich rozliczanie','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('330040000','Odhylenia cen ewidencyjnych od rzeczywistych cen nabycia lub zakupu','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('330050000','Koszty zakupu zawarte w fakturach dostawcw','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('330060000','Opaty manipulacyjne policzone przez Urzd Celny','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('330070000','Niedobory, szkody i nadwyki w transporcie','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('330080000','Znaki akcyzy wedug dokumentu SAD','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('330090000','Reklamacje faktur dostawcw','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('331000000','Materiay','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('331010000','Materiay w magazynach wasnych','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('331020000','Materiay w magazynach obcych','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('331030000','Materiay w przerobie','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('333000000','Towary','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('333010000','Towary w magazynach wasnych','A','','A','IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('333020000','Towary w magazynach obcych','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('333030000','Towary w detalu','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('334000000','Odchylenia od cen ewidencyjnych materiaw i towarw','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('334010000','Odpisy aktualizujce warto materiaw','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('334020000','Odpisy aktualizujce warto towarw','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('400000000','Koszty wedug rodzajw i ich rozlicze','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440000000','Koszty wedug rodzajw','A','','E','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440010000','Zuycie materiaw i energii','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440010100','Zuycie materiaw biurowych','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440020000','Usugi obce','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440020100','Usugi celne','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440020200','Usugi telekomunikacyjne','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440020300','Usugi pocztowe','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440020400','Usugi kurierskie i transportowe','A','','E','AP_amount:IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440020500','Analizy sanitarne','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440020600','Usugi graficzne i drukarskie','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440030000','Podatki i opaty','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440030100','Opaty i prowizje bankowe','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440030200','Opaty sdowe, prawnicze i notarialne','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440030300','Opaty skarbowe','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440030400','Koncesje','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('440040000','Wynagrodzenia za prac','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('441000000','wiadczenia na rzecz pracownikw','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('442000000','Amortyzacja','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('443000000','Pozostae','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('449000000','Rozliczenie kosztw','A','','E','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('449010000','Nie podlegajce rozliczeniu w czasie','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('449020000','Przypadajce na przysze okresy','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('449030000','Koszty zgromadzone','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('449040000','Koszty nie wliczane do wartoci sprzeday','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('500000000','Koszty wedug typw dziaalnoci i ich rozliczenie','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('550000000','Koszty dziaalnoci podstawowej-produkcyjnej','A','','E','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('550010000','Rozliczone koszta dziaalnoci','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('550020000','Koszty nie zakoczonych dugotrwaych usug','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('550030000','Straty zwizane z wykonaniem dugotrwaych usug','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('552000000','Koszty dziaalnoci podstawowej-handlowej','A','','E','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('552010000','Koszty utrzymania punktw sprzeday detalicznej','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('550200000','Koszty utrzymania hurtowni','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('552030000','Koszty sprzeday wyrobw','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('552040000','Podatek akcyzowy','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('552050000','Opaty celne','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('553000000','Koszty dziaalnoci pomocniczej','A','','E','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('553010000','wiadczenia usug transportowych','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('555000000','Koszty zarzdu','A','','E','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('555010000','Koszty zarzdzania jednostk','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('555020000','wiadczenia usug na potrzeby reprezentacji i reklamy','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('558000000','Rozliczenie kosztw dziaalnoci','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('600000000','Produkty i rozliczenia midzyokresowe','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('660000000','Pprodukty i produkty w toku','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('661000000','Produkty gotowe','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('661010000','Wyroby gotowe','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('661020000','Wyroby poza jednostk','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('662000000','Odchylenia od cen ewidencyjnych produktw','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('662010000','Odchylenia od cen evidencyjnych wyrobw gotowych','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('662020000','Odhylenia od cen evidencyjnych pfabrykatw','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('664000000','Rozliczenia midzyokresowe kosztw','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('664010000','Czynne rozliczenia midzyokresowe kosztw','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('664020000','Bierne rozliczenia midzyokresowe kosztw','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('665000000','Pozostae rozliczenia midzyokresowe','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('665010000','Czynne rozliczenia przyszych okresw','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('665020000','Bierne rozliczenia przyszych okresw','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('700000000','Przychody i koszty zwizane z ich osigniciem','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('770000000','Sprzeda produktw','A','','I','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('770010000','Sprzeda produktw na kraj','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('770020000','Sprzeda produktw na eksport','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('770030000','Sprzeda usug na kraj','A','','I','AR_amount:IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('770040000','Sprzeda usug na eksport','A','','I','AR_amount:IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('770100000','Koszty sprzedanych produktw','A','','E','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('770110000','Koszt wasny sprzeday produktw na kraj','A','','E','IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('770120000','Koszt wasny sprzeday produktw na eksport','A','','E','IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('770130000','Koszt wasny sprzeday usug na kraj','A','','E','IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('770140000','Koszt wasny sprzeday usug na export','A','','E','IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('773000000','Sprzeda towarw','A','','I','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('773010000','Sprzeda hurtowa towarw','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('773020000','Sprzeda detaliczna towarw','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('773030000','Sprzeda wysykowa towarw','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('773040000','Prowizja komisowa','A','','I','AR_amount:IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('773100000','Warto sprzedanych towarw w cenach zakupu','A','','E','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('773110000','Warto sprzedanych towarw w sprzeday hurtowej','A','','E','IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('773120000','Warto sprzedanych towarw w sprzeday detalicznej','A','','E','IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('773130000','Warto sprzedanych towarw w sprzeday wysykowej','A','','E','IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('773140000','Prowizja komisowa','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('774000000','Sprzeda materiaw','A','','I','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('774010000','Materiay','A','','I','AP_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('774020000','Opakowania','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('774030000','Odpady','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('774100000','Warto sprzedanych materiaw','A','','E','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('774110000','Warto w cenach zakupu sprzedanych materiaw','A','','E','IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('774120000','Warto w cenach zakupu sprzedanych opakowa','A','','E','IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('774130000','Warto w cenach zakupu sprzedanych odpadw','A','','E','IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('775000000','Przychody finansowe','A','','I','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('775010000','Kwoty nalene ze sprzeday aktyww finansowych','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('775020000','Kwoty nalene z tytuu dywident','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('775030000','Otrzymane odsetki','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('775040000','Przychody ze zbycia investycji','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('775050000','Aktualizacja wartoci investycji-przychody','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('775060000','Dodatnie rnice kursu walut','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('775070000','Pozostae przychody finansowe','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('775100000','Koszty finansowe','A','','E','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('775110000','Warto sprzedanych investycji','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('775120000','Odpisy z tytuu utraty wartoci investycji-koszty','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('775130000','Odsetki zapacone','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('775140000','Ujemne rnice kursu walut','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('775190000','Pozostae koszty finansowe','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('776000000','Pozostae przychody operacyjne','A','','I','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('776010000','Przychody ze zbycia niefinansowych aktyww trwaych','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('776020000','Otrzymane dotacje','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('776030000','Przychody z usug socjalnych','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('776040000','Przychody ze wzrostu wartoci niefinansowych aktyww trwaych','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('776090000','Inne pozostae przychody operacyjne','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('776100000','Pozostae koszty operacyjne','A','','E','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('776110000','Warto sprzedanych niefinansowych aktyww trwaych','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('776120000','Dotacje przekazane','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('776130000','Odpisy z tytuu utraty wartoci aktyww niefinansowych','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('776140000','Inne pozostae koszty operacyjne','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('777000000','Zyski nadzwyczajne','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('777100000','Straty nadzwyczajne','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('779000000','Obroty wewntrzne','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('779010000','Koszt wyrobw wasnej produkcji wydanych do wasnych sklepw','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('779020000','wiadczenia na rzecz rodkw trwaych w budowie','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('779040000','Koszt niedoborw produktw','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('779050000','Koszt zaniechania okrelonego rodzaju dziaalnoci','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('779100000','Koszt obrotw wewntrznych','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('779110000','Koszt wytworzenia wyrobw gotowych wydanych do wasnych sklepw','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('779120000','Koszt wytworzenia wiadcze na rzecz rodkw trwaych w budowie','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('779130000','Koszt wytworzenia zakoczonych prac rozwojowych','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('779140000','Koszt wytworzenia produktw uznanych za niedobory','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('779150000','Koszt zaniechania okrelonego rodzaju dziaalnoci','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('800000000','Kapitay wasne i wynik finansowy','H','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('880000000','Kapita podstawowy','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('880010000','Kapita zakadowy','A','','Q','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('881000000','Fundusze wydzielone jednostkom zalenym','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('882000000','Nalene wpaty na kapita podstawowy','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('883000000','Fundusze wydzielone jednostkom zalenym','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('884000000','Kapita zapasowy','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('885000000','Kapita rezerwowy','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('886000000','Kapita z aktualizacji wyceny','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('887000000','Rozliczenia wyniku finansowego','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('888000000','Rezerwy','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('888010000','Rezerwa z tytuu odroczonego podatku dochodowego','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('888020000','Rezerwa na wiadczenia','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('888020100','Rezerwa dugoterminowa na wiadczenia emerytalne i podobne','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('888020200','Rezerwa krtkoterminowa na wiadczenia emerytalne i podobne','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('889090000','Pozostae rezerwy','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('889090100','Pozostae rezerwy dugoterminowe','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('889090200','Pozostae rezerwy krtkoterminowe','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('890000000','Rozliczenia midzyokresowe','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('890010000','Ujemna warto firmy','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('890020000','Inne rozliczenia midzyokresowe','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('890020100','Inne rozliczenia midzyokresowe dugoterminowe','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('890020200','Inne rozliczenia midzyokresowe krtkoterminowe','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('891000000','Fundusze specjalne','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('892000000','Wynik finansowy','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('893000000','Odpisy z zysku netto w cigu roku obrotowego','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('893010000','Podatek dochodowy','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('893020000','Inne obowizkowe obcienia wyniku finansowego','A','','Q','');
--
insert into tax (chart_id,rate) values ((select id from chart where accno = '223020100'),0.22);
insert into tax (chart_id,rate) values ((select id from chart where accno = '223020200'),0.07);
insert into tax (chart_id,rate) values ((select id from chart where accno = '223020300'),0);
insert into tax (chart_id,rate) values ((select id from chart where accno = '223030100'),0.22);
insert into tax (chart_id,rate) values ((select id from chart where accno = '223030200'),0.07);
insert into tax (chart_id,rate) values ((select id from chart where accno = '223030300'),0);
--
update defaults set inventory_accno_id = (select id from chart where accno = '333000000'), income_accno_id = (select id from chart where accno = '773010000'), expense_accno_id = (select id from chart where accno = '773110000'), fxgain_accno_id = (select id from chart where accno = '775060000'), fxloss_accno_id = (select id from chart where accno = '775140000'), invnumber = '1000', sonumber = '1000', ponumber = '1000', curr = 'PLN:USD:EUR', weightunit = 'kg';
--


